### Name: cumres.coxph
### Title: Calculates GOF measures for Cox's propoportional hazard model
###   for right censored survival times
### Aliases: cumres.coxph
### Keywords: models regression

### ** Examples

library(survival)

simcox <- function(n=100, seed=1) {
  if (!is.null(seed))
    set.seed(seed)
  require(survival)
  time<-rexp(n); cen<-2*rexp(n); 
  status<-(time<cen); 
  time[status==0]<-cen[status==0]; 
  X<-matrix(rnorm(2*n),n,2)  
  return(data.frame(time=time, status=status, X))
}
n <- 100; d <- simcox(n); model <- coxph(Surv(time,status)~ X1 + X2, data=d, robust=TRUE)

dtimes <- sort(d$time[d$status==1])
system.time(a <- cumres(model))
summary(a)

## PBC example
data(pbc)
fit.cox <- coxph(Surv(time,status) ~ age + edema + bili + protime, data=pbc)
system.time(pbc.gof <- cumres(fit.cox,R=2000))
par(mfrow=c(2,2))
plot(pbc.gof, ci=TRUE, legend=NULL)




